#
# ramcpackage.macro	1.0
#	This macro packages all the ramcs in a project
#
#
# Author:	Modeliosoft
#
# Applicable on:
#
# Version history:
# 1.0	 14th April 2010	 - creation
#
#
import os
from com.modeliosoft.modelio.api.modelio import Modelio 
from java.util import HashSet
from java.io import File

def findCxxDesigner(session):
	# Find the Cxx module peer mdac
	cxxMdac = None
	for module in session.getAllPeerMdacs():
		if (module.getName() == "CxxDesigner"):
			return module;
def findRAMCS(root):
	ramcs = []
	for artifact in root.getOwnedElement(IArtifact):
		if (artifact.isStereotyped("ModelComponentArchive")):
			ramc = artifact
			tags = ramc.getTagValues("ModelComponentVersion")
			if (len(tags) > 0):
				version = tags[0]
			else:
				version = ""
			ramcs.append( (ramc, version) )
	return ramcs

def cleanupRAMC(session, ramc):
	mc, version = ramc
	archiveFile = File(makeArchiveDirectory(session), makeArchiveName(ramc))
	fname = mc.getFileName()
	if (os.path.isfile(fname)):
		os.remove(fname)

def declareRAMC(session, ramc):
	print "Declaring ", ramc
	mc, version = ramc
	latestBuild = os.path.join(makeArchiveDirectory(session), "latestbuild.txt")
	print " latestbuild file = ", latestBuild
	f = open(latestBuild, 'a')
	f.write(makeArchiveName(ramc) + "\n")
	print " added line = ", makeArchiveName(ramc)
	f.close()

def makeArchiveName(ramc):
	mc, version = ramc
	mcBaseName = os.path.splitext(os.path.basename(mc.getFileName()))[0]
	return mcBaseName + "_" + version + ".ramc"

def makeArchiveDirectory(session):
	directory = os.path.join(Modelio.getInstance().getContext().getProjectSpacePath().getAbsolutePath(), "builds")
	if (not os.path.exists(directory)): os.makedirs(directory)
	return directory

def packageRAMC(session, ramc):
	print "Packaging ", ramc
	mc, version = ramc
	packager = Modelio.getInstance().getModelComponentService()
	peerMdacs = HashSet()
	cxxDesigner = findCxxDesigner(modelingSession)
	if (not cxxDesigner is None):
		peerMdacs.add(cxxDesigner)
	archiveFile = File(makeArchiveDirectory(modelingSession), makeArchiveName(ramc))
	packager.packageModelComponent(mc, peerMdacs, archiveFile, None)
	print "BUILD RAMC =", archiveFile


def main():
	latestBuild = os.path.join(makeArchiveDirectory(modelingSession), "latestbuild.txt")
	if os.path.isfile(latestBuild):
		os.remove(latestBuild)
	f = open(latestBuild, 'w')
	f.close()
			
	for ramc in findRAMCS(modelingSession.getModel().getRoot()):
		cleanupRAMC(modelingSession, ramc)
		packageRAMC(modelingSession, ramc)
		declareRAMC(modelingSession, ramc)

# call main
main()
				
				 
