#
# ramcpackage.macro  1.0
#  This macro refreshes the deployment of the ramcs currently configured in the project
#  taking the RAMC archive from the hotspace
#
#
# Author:  Modeliosoft
#
# Applicable on:
#
# Version history:
# 1.0   14th April 2010   - creation
#
#
import os
import shutil
from com.modeliosoft.modelio.api.model import ObUtils
from com.modeliosoft.modelio.ramcs.deployer import RamcDeployer
from java.util import HashSet
from java.io import File
from com.modeliosoft.modelio.core.app import O


def findRAMCS(root):
  ramcs = []
  for component in root.getOwnedElement(ObComponent):
    if (component.isStereotyped("ModelComponent")):
      ramc = component
      for artifact in ramc.getOwnedElement(ObArtifact):
        if (artifact.isStereotyped("ModelComponentArchive")):
          tags = ObUtils.getTagValues(artifact, "ModelComponentVersion")
          if (len(tags) > 0):
            version = tags[0]
          else:
            version = ""
          ramcs.append( (artifact, version) )
  return ramcs


def cleanupRAMC(session, ramc):
        mc, version = ramc
        path_to_clean = makeLocalRAMCDirectory(session, ramc)
        print " - Cleaning up local directory: ", path_to_clean
        if os.path.isdir(path_to_clean) or os.path.isfile(path_to_clean):
      		shutil.rmtree(path_to_clean, True)        
        

def makeArchiveName(ramc):
        mc, version = ramc
        hotspace = os.path.join("\\\\mercure\\sirius$\\hotspace\\ramcs", mc.getName(), version)
        name = mc.getName() + "_" + version + ".ramc"
        return os.path.join(hotspace, name) 

def makeLocalRAMCDirectory(session, ramc):
        mc, version = ramc
        directory = os.path.join(session.getProjectSpacePath().getAbsolutePath(), mc.getName())
        return directory

def deployRAMC(session, ramc):
        mc, version = ramc
        ramcArchive = makeArchiveName(ramc)
        print " - Deploying ", ramcArchive
        deployer = RamcDeployer()
        # secret access to the real ModelingSession 
	_sess = O.getDefault().getModelingSession()
        deployer.deployRamc(_sess, File(ramcArchive), File(session.getProjectSpacePath().getAbsolutePath()), None )
        
        
        

def main():
        for ramc in findRAMCS(modelingSession.getModel().getRoot()):
          print "Redeploying ramc:", ramc[0].getName(), ramc[1]
          cleanupRAMC(modelingSession, ramc)
          deployRAMC(modelingSession, ramc)
          



# call main
main()
        
         
